<?php
/**
 * EDD mailketing class, extension of the EDD base newsletter classs
 *
 * @copyright   Copyright (c) 2013, Pippin Williamson
 * @license     http://opensource.org/licenses/gpl-2.0.php GNU Public License
 * @since       1.0
*/
class EDD_mailketing extends EDD_Newsletter {

	/**
	 * mailketing API Key
	 *
	 * @var string
	 */
	public $api_key;


	/**
	 * Convert kit account tags
	 *
	 * @var object
	 */
	public $tags;

	/**
	 * Sets up the checkout label
	 */
	public function init() {

		if( ! function_exists( 'edd_get_option' ) ) {
			return;
		}
    $options = get_option( "mailketingsmtp_options" );
		$this->checkout_label = edd_get_option( 'edd_mailketing_label', __( 'Signup for the newsletter', 'edd-mailketing' ) );
		$this->api_key        = $options['mailketingsmtp_api'];
		add_filter( 'edd_settings_sections_extensions', array( $this, 'subsection' ), 10, 1 );
		add_filter( 'edd_settings_extensions_sanitize', array( $this, 'save_settings' ) );

	}


	/**
	 * Retrieves the lists from mailketing
	 */
	public function get_lists() {
    $options = get_option( "mailketingsmtp_options" );
    $url='https://api.mailketing.co.id/API/getLists';
    $response = wp_remote_get( $url, array(
        'APIToken'    => $options['mailketingsmtp_api'],
        'headers' => array(
            'APIToken' => $options['mailketingsmtp_api'],
        ),
    ) );

    $ua=wp_remote_retrieve_body($response);
    $has = json_decode($ua,true);
    $lists=$has['response']['list'];

			if( ! empty( $lists ) ) {

				foreach( $lists as $list ) {

					$this->lists[ $list['list_id'] ] = $list['list_name'];

				}

			}



		return (array) $this->lists;
	}


	/**
	 * Register our subsection for EDD 2.5
	 *
	 * @since  1.0.3
	 * @param  array $sections The subsections
	 * @return array           The subsections with mailketing added
	 */
	function subsection( $sections ) {
		$sections['mailketing'] = __( 'mailketing', 'edd-mailketing' );
		return $sections;
	}

	/**
	 * Registers the plugin settings
	 */
	public function settings( $settings ) {

		$edd_mailketing_settings = array(
			array(
				'id'      => 'edd_mailketing_settings',
				'name'    => '<strong>' . __( 'mailketing Settings', 'edd-mailketing' ) . '</strong>',
				'desc'    => __( 'Configure mailketing Integration Settings', 'edd-mailketing' ),
				'type'    => 'header'
			),
			array(
				'id'      => 'edd_mailketing_show_checkout_signup',
				'name'    => __( 'Show Signup on Checkout', 'edd-mailketing' ),
				'desc'    => __( 'Allow customers to signup for the list selected below during checkout?', 'edd-mailketing' ),
				'type'    => 'checkbox',
				'tooltip_title' => __( 'Signup on Checkout', 'edd-mailketing' ),
				'tooltip_desc'  => __( 'If enabled, a checkbox will be shown on the checkout screen allowing customers to opt-into an email subscription. If not enabled, customers will be subscribed only if one or more Forms is selected from the Edit screen of the Download product(s) being purchased.', 'edd-mailketing' )
			),
			array(
				'id'      => 'edd_mailketing_list',
				'name'    => __( 'Choose a List', 'edd-mailketing'),
				'desc'    => __( 'Select the List you wish to subscribe buyers to. The form can also be selected on a per-product basis from the product edit screen', 'edd-mailketing' ),
				'type'    => 'select',
				'options' => $this->get_lists()
			)
		);

		if ( version_compare( EDD_VERSION, 2.5, '>=' ) ) {
			$edd_mailketing_settings = array( 'mailketing' => $edd_mailketing_settings );
		}

		return array_merge( $settings, $edd_mailketing_settings );
	}

	/**
	 * Flush the list transient on save
	 */
	public function save_settings( $input ) {
		if( isset( $input['edd_mailketing_api'] ) ) {
			delete_transient( 'edd_mailketing_list_data' );
			delete_transient( 'edd_mailketing_tag_data' );
		}
		return $input;
	}

	/**
	 * Display the metabox, which is a list of newsletter lists
	 */
	public function render_metabox() {

		global $post;

		echo '<p>' . __( 'Select the form you wish buyers to be subscribed to when purchasing.', 'edd-mailketing' ) . '</p>';

		$checked = (array) get_post_meta( $post->ID, '_edd_' . esc_attr( $this->id ), true );
		foreach( $this->get_lists() as $list_id => $list_name ) {
			echo '<label>';
				echo '<input type="checkbox" name="_edd_' . esc_attr( $this->id ) . '[]" value="' . esc_attr( $list_id ) . '"' . checked( true, in_array( $list_id, $checked ), false ) . '>';
				echo '&nbsp;' . $list_name;
			echo '</label><br/>';
		}

	}

	/**
	 * Save the metabox
	 *
	 * @params array $fields
	 */
	public function save_metabox( $fields ) {

		$fields[] = '_edd_' . esc_attr( $this->id );
		return $fields;
	}

	/**
	 * Determines if the checkout signup option should be displayed
	 */
	public function show_checkout_signup() {
		global $edd_options;

		return ! empty( $edd_options['edd_mailketing_show_checkout_signup'] );
	}

	/**
	 * Check if a customer needs to be subscribed on completed purchase of specific products
	 *
	 * @param int $download_id ID of purchased download
	 * @param int $payment_id ID of payment
	 * @param string $download_type Type of download
	 */
	public function completed_download_purchase_signup( $download_id = 0, $payment_id = 0, $download_type = 'default' ) {

		$subscribed = false;
		$user_info  = edd_get_payment_meta_user_info( $payment_id );
		$lists      = get_post_meta( $download_id, '_edd_' . $this->id, true );
		$payment    = new EDD_Payment( $payment_id );

		if( 'bundle' == $download_type ) {

			// Get the lists of all items included in the bundle

			$downloads = edd_get_bundled_products( $download_id );
			if( $downloads ) {
				foreach( $downloads as $d_id ) {
					$d_lists = get_post_meta( $d_id, '_edd_' . $this->id, true );
					if ( is_array( $d_lists ) ) {
						$lists = array_merge( $d_lists, (array) $lists );
					}
				}
			}
		}

		if( empty( $lists ) ) {
			if ( $ret ) {
				$payment->add_meta( 'mailketing_subscription', true );
			}
			return;
		}

		$lists = array_unique( $lists );

		foreach( $lists as $list ) {

			$ret = $this->subscribe_email( $user_info, $list, false );
			if( $ret ) {
				$subscribed = true;
			}

		}

		if( $subscribed ) {
			$payment->add_meta( 'mailketing_subscription', true );
		}

	}

	/**
	 * Records purchase record for customer after a purchase is completed
	 *
	 * @param int $payment_id ID of payment
	 *
	 * @return void
	 */

	/**
	 * Subscribe an email to a list
	 *
	 * @param array $user_info User info as returned by edd_get_payment_meta_user_info()
	 * @param bool|string $list_id Optional. ID of list to subscribe to. If false, the default, value saved in UI will be used.
	 * @param bool $opt_in_overridde Not used
	 * @param array $tags Optional. Optional. Array of tags to add to subscriber
	 *
	 * @return bool
	 */
	public function subscribe_email( $user_info = array(), $list_id = false, $opt_in_overridde = false ) {

		// Retrieve the global list ID if none is provided
		if( ! $list_id ) {
			$list_id = edd_get_option( 'edd_mailketing_list', false );
			if( ! $list_id ) {
				return false;
			}
		}
		$mobile="";
		if(isset($user_info['phone_number'])){
			$mobile=$user_info['phone_number'];
		}
    $options = get_option( "mailketingsmtp_options" );
      $url='https://api.mailketing.co.id/api/v1/addsubtolist';
      $args = array(
          'method' => 'POST',
          'timeout' => '10',
              'blocking' => false,
          'headers'  => array(
              'Content-type: application/x-www-form-urlencoded'
          ),
          'sslverify' => true,
          'body' => array(
            'first_name'    => $user_info['first_name'],
            'email'    => $user_info['email'],
						'mobile'	=> $mobile,
            'last_name'    => $user_info['last_name'],
            'api_token'    => $options['mailketingsmtp_api'],
            'list_id'	=> $user_info['email']
          )
      );
      $response = wp_remote_post( $url,$args);
      $response=wp_remote_retrieve_body($response);


		return true;

	}

}
